package com.xylink.config;

import com.xylink.util.SignUtil;
import org.apache.commons.lang3.StringUtils;

import java.util.Map;
import java.util.concurrent.locks.ReentrantLock;

/**
 * Created by wenya on 17/9/11.
 */
public class SDKConfig {
    private String serverHost;
    private String accessToken;
    private String refreshToken;
    private String xyClientid;
    private String xyClientSecret;
    private String enterpriseId;
    private String xySignSecret;
    private SignUtil.SignType signType;
    //accessToken过期时间（秒）
    private Long accessTokenExpireIn;
    //是否开启安全的https方法
    private boolean enableSecurityHttp = false;
    private Map<String,String> extrasHeader;

    private SignatureVersion signatureVersion = SignatureVersion.Signature_1_0;

    Long timeLag = 0L;

    Long updateTime = 0L;

    private final ReentrantLock reentrantLock = new ReentrantLock();

    public SDKConfig() {
    }

    public SDKConfig(EnterpriseSdkConfig enterpriseSdkConfig) {
        this.serverHost = enterpriseSdkConfig.getServerHost();
        this.enterpriseId = enterpriseSdkConfig.getEnterpriseId();
        this.xyClientid = enterpriseSdkConfig.getClientId();
        this.xyClientSecret = enterpriseSdkConfig.getClientSecret();
        this.signatureVersion = enterpriseSdkConfig.getSignatureVersion();
        this.signType = enterpriseSdkConfig.getSignType();
        this.extrasHeader = enterpriseSdkConfig.getExtrasHeader();
        this.enableSecurityHttp = enterpriseSdkConfig.isEnableSecurityHttp();
    }

    public void check(){
        if (StringUtils.isBlank(this.serverHost)
                || StringUtils.isBlank(this.enterpriseId)
                || StringUtils.isBlank(this.xyClientid)
                || StringUtils.isBlank(this.xyClientSecret)
                ||  null == this.signType
                ||  null == this.signatureVersion
        ){
            throw new IllegalArgumentException("serverHost、enterpriseId、xyClientid、xyClientSecret、signType、signatureVersion should be init");
        }

        if (!signatureVersion.isNewSign()){
            throw new IllegalArgumentException("init method only support new signatureVersion, not support 1.0");
        }
    }

    public boolean isEnableSecurityHttp() {
        return enableSecurityHttp;
    }

    public void setEnableSecurityHttp(boolean enableSecurityHttp) {
        this.enableSecurityHttp = enableSecurityHttp;
    }

    public SignatureVersion getSignatureVersion() {
        return signatureVersion;
    }

    public void setSignatureVersion(SignatureVersion signatureVersion) {
        this.signatureVersion = signatureVersion;
    }

    public String getServerHost() {
        return serverHost;
    }

    public void setServerHost(String serverHost) {
        this.serverHost = serverHost;
    }

    public String getAccessToken() {
        return accessToken;
    }

    public void setAccessToken(String accessToken) {
        this.accessToken = accessToken;
    }

    public String getXyClientid() {
        return xyClientid;
    }

    public void setXyClientid(String xyClientid) {
        this.xyClientid = xyClientid;
    }

    public String getXyClientSecret() {
        return xyClientSecret;
    }

    public void setXyClientSecret(String xyClientSecret) {
        this.xyClientSecret = xyClientSecret;
    }

    public String getEnterpriseId() {
        return enterpriseId;
    }

    public void setEnterpriseId(String enterpriseId) {
        this.enterpriseId = enterpriseId;
    }

    public String getRefreshToken() {
        return refreshToken;
    }

    public void setRefreshToken(String refreshToken) {
        this.refreshToken = refreshToken;
    }

    public Long getAccessTokenExpireIn() {
        return accessTokenExpireIn;
    }

    public void setAccessTokenExpireIn(Long accessTokenExpireIn) {
        this.accessTokenExpireIn = accessTokenExpireIn;
    }

    public String getXySignSecret() {
        return xySignSecret;
    }

    public void setXySignSecret(String xySignSecret) {
        this.xySignSecret = xySignSecret;
    }

    public SignUtil.SignType getSignType() {
        return signType;
    }

    public void setSignType(SignUtil.SignType signType) {
        this.signType = signType;
    }

    public Map<String, String> getExtrasHeader() {
        return extrasHeader;
    }

    public void setExtrasHeader(Map<String, String> extrasHeader) {
        this.extrasHeader = extrasHeader;
    }

    public Long getTimeLag() {
        return timeLag;
    }

    public void setTimeLag(Long timeLag) {
        this.timeLag = timeLag;
    }

    public Long getUpdateTime() {
        return updateTime;
    }

    public void setUpdateTime(Long updateTime) {
        this.updateTime = updateTime;
    }

    public ReentrantLock getReentrantLock() {
        return reentrantLock;
    }

    @Override
    public String toString() {
        return "SDKConfig{" +
                "serverHost='" + serverHost + '\'' +
                ", accessToken='" + accessToken + '\'' +
                ", refreshToken='" + refreshToken + '\'' +
                ", xyClientid='" + xyClientid + '\'' +
                ", xyClientSecret='" + xyClientSecret + '\'' +
                ", enterpriseId='" + enterpriseId + '\'' +
                ", xySignSecret='" + xySignSecret + '\'' +
                ", signType=" + signType +
                ", accessTokenExpireIn=" + accessTokenExpireIn +
                ", enableSecurityHttp=" + enableSecurityHttp +
                ", extrasHeader=" + extrasHeader +
                ", signatureVersion=" + signatureVersion +
                ", timeLag=" + timeLag +
                ", updateTime=" + updateTime +
                '}';
    }
}
