package com.xylink.sdk.face;

import com.fasterxml.jackson.databind.ObjectMapper;
import com.xylink.config.SDKConfigMgr;
import com.xylink.model.*;
import com.xylink.util.HttpUtil;
import com.xylink.util.Result;
import com.xylink.util.SignatureSample;
import java.io.IOException;
import java.util.List;

/**
 * Created with IntelliJ IDEA.
 * Description:
 * User: gzm
 * Date: 2019-03-04
 */
public class AiFaceApi {

    private static SignatureSample signatureSample = new SignatureSample();
    private static final String prefixUrl = "/api/rest/external/v1/face";
    private static final ObjectMapper objectMapper = new ObjectMapper();

    public Result createUser(String enterpriseId, String token, CreateFaceUserInfoReq createFaceUserInfoReq) throws IOException{
        String surl = getPrefixUrl(enterpriseId) + "/createUser" + "?enterpriseId=" + enterpriseId;
        String jsonEntity = objectMapper.writeValueAsString(createFaceUserInfoReq);
        surl = signatureSample.appendSigniture(jsonEntity,"POST",token,surl);

        return HttpUtil.getResponse(surl,"POST", jsonEntity,String.class);

    }

    public Result getUserInfoByUserId(String enterpriseId, String token, long faceUserId) throws IOException{
        String surl = getPrefixUrl(enterpriseId) + "/userInfo" + "?enterpriseId=" + enterpriseId+"&faceUserId="+faceUserId;
        surl = signatureSample.appendSigniture("","GET",token,surl);

        return HttpUtil.getResponse(surl,"GET", "",String.class);

    }

    public Result getUserInfoByUserIdBatch(String enterpriseId, String token, List faceUserIds) throws IOException{
        String surl = getPrefixUrl(enterpriseId) + "/batch/userInfo" + "?enterpriseId=" + enterpriseId;
        String jsonEntity = objectMapper.writeValueAsString(faceUserIds);
        surl = signatureSample.appendSigniture(jsonEntity,"PUT",token,surl);

        return HttpUtil.getResponse(surl,"PUT", jsonEntity,String.class);

    }

    public Result getUserIdsByuserIdentifyId(String enterpriseId, String token, String userIdentifyId) throws IOException{
        String surl = getPrefixUrl(enterpriseId) + "/identify/faceUserInfo" + "?enterpriseId=" + enterpriseId+"&userIdentifyId="+userIdentifyId;
        surl = signatureSample.appendSigniture("","GET",token,surl);

        return HttpUtil.getResponse(surl,"GET", "",String.class);

    }

    public Result deleteUser(String enterpriseId, String token, long faceUserId) throws IOException{
        String surl = getPrefixUrl(enterpriseId) + "/deleteUser" + "?enterpriseId=" + enterpriseId+"&faceUserId="+faceUserId;
        surl = signatureSample.appendSigniture("","DELETE",token,surl);

        return HttpUtil.getResponse(surl,"DELETE", "",String.class);

    }

    public Result updateUser(String enterpriseId, String token, List<FaceUserInfo> userInfos) throws IOException{
        String surl = getPrefixUrl(enterpriseId) + "/update" + "?enterpriseId=" + enterpriseId;
        String jsonEntity = objectMapper.writeValueAsString(userInfos);
        surl = signatureSample.appendSigniture(jsonEntity,"POST",token,surl);

        return HttpUtil.getResponse(surl,"POST", jsonEntity,String.class);

    }

    public Result uploadFace(String enterpriseId, String token, FaceUploadReq faceUploadReq) throws IOException{

        String surl = getPrefixUrl(enterpriseId) + "/uploadFace" + "?enterpriseId=" + enterpriseId;
        String jsonEntity = objectMapper.writeValueAsString(faceUploadReq);
        surl = signatureSample.appendSigniture(jsonEntity,"POST",token,surl);

        return HttpUtil.getResponse(surl,"POST", jsonEntity,String.class);

    }

    /**
     * get all nemo status in the enterprise,if Result Object's success is true,the "data" type of Result is DeviceInfo[];if not, the "data" type of Result is RestMessage
     * @param enterpriseId
     * @param token
     * @return
     * @throws IOException
     */
    public Result deleteUserFace(String enterpriseId, String token, UserFaceReq userFaceReq) throws IOException{

        String surl = getPrefixUrl(enterpriseId) + "/deleteUserFace"  + "?enterpriseId=" + enterpriseId;
        String jsonEntity = objectMapper.writeValueAsString(userFaceReq);
        surl = signatureSample.appendSigniture(jsonEntity,"DELETE",token,surl);

        return HttpUtil.getResponse(surl,"DELETE", jsonEntity,String.class);

    }

    public Result allUsersInfo(String enterpriseId, String token, Integer pageIndex, Integer pageSize) throws IOException{
        String surl = getPrefixUrl(enterpriseId) + "/allUsersInfo" + "?enterpriseId=" + enterpriseId+"&pageIndex="+pageIndex+"&pageSize="+pageSize;
        surl = signatureSample.appendSigniture("","GET",token,surl);

        return HttpUtil.getResponse(surl,"GET", "",String.class);

    }
    private String getPrefixUrl(String enterpriseId) {
        return SDKConfigMgr.getServerHost(enterpriseId) + prefixUrl;
    }
}
