package com.xylink.util;

/**
 * Created by wangdecheng on 2019/4/22.
 */

import com.xylink.config.SDKConfigMgr;
import com.xylink.log.XyLinkLog;
import org.apache.commons.httpclient.HttpClient;
import org.apache.commons.httpclient.HttpStatus;
import org.apache.commons.httpclient.methods.GetMethod;
import org.apache.commons.httpclient.params.HttpMethodParams;

import java.io.IOException;
import java.io.InputStream;
import java.util.HashMap;
import java.util.Map;


/**
 * <p>Http工具类
 *
 * <p>Http工具类，为系统提供通用Http访问操作方法：
 *
 * <p>1、发送GET请求；
 * <p>2、发送POST请求。
 *
 */
public class HttpUtil2 {
    private static XyLinkLog logger = SDKConfigMgr.getXyLinkLog();


    /**
     * <p>发送GET请求
     *
     * @param  url GET请求地址
     *
     * @return 与当前请求对应的响应内容字节数组
     *
     */
    public static byte[] doGet(String url) {

        return HttpUtil2.doGet(url , null , null , 0);
    }

    /**
     * <p>发送GET请求
     *
     * @param  url       GET请求地址
     * @param  headerMap GET请求头参数容器
     *
     * @return 与当前请求对应的响应内容字节数组
     *
     */
    public static byte[] doGet(String url , Map headerMap) {

        return HttpUtil2.doGet(url , headerMap , null , 0);
    }

    /**
     * <p>发送GET请求
     *
     * @param  url       GET请求地址
     * @param  proxyUrl  代理服务器地址
     * @param  proxyPort 代理服务器端口号
     *
     * @return 与当前请求对应的响应内容字节数组
     *
     * @modify 窦海宁, 2012-03-19
     */
    public static byte[] doGet(String url , String proxyUrl , int proxyPort) {

        return HttpUtil2.doGet(url , null , proxyUrl , proxyPort);
    }

    /**
     * <p>发送GET请求
     *
     * @param  url       GET请求地址
     * @param  headerMap GET请求头参数容器
     * @param  proxyUrl  代理服务器地址
     * @param  proxyPort 代理服务器端口号
     *
     * @return 与当前请求对应的响应内容字节数组
     *
     * @modify 窦海宁, 2012-03-19
     */
    public static byte[] doGet(String url , Map headerMap , String proxyUrl , int proxyPort) {

        byte[]     content    = null;
        HttpClient httpClient = new HttpClient();
        GetMethod getMethod  = new GetMethod(url);


        //设置成了默认的恢复策略，在发生异常时候将自动重试3次，在这里你也可以设置成自定义的恢复策略
        getMethod.getParams().setParameter(HttpMethodParams.SO_TIMEOUT , 10000);
        //postMethod.getParams().setParameter(HttpMethodParams.RETRY_HANDLER , new DefaultHttpMethodRetryHandler());
        InputStream inputStream = null;
        try {

            if (httpClient.executeMethod(getMethod) == HttpStatus.SC_OK) {

                //读取内容
                inputStream = getMethod.getResponseBodyAsStream();
            } else {

                logger.error("Method failed: " + getMethod.getStatusLine());
            }
        } catch (IOException ex) {

            ex.printStackTrace();
        } finally {

            try {
                inputStream.close();
            } catch (IOException e) {
                e.printStackTrace();
            }
            getMethod.releaseConnection();
        }
        return content;
    }






    public static void main(String[] args) {
        Map<String, String> map = new HashMap<String, String>();
        map.put("wd", "nima");
        byte[] b = doGet("http://www.baidu.com", map);
        System.out.println("-------------------"+new String(b));
    }

}
